# Copyright 2025 Clivern
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging


class Logger:
    """
    The Logger class provides a centralized way to manage and retrieve logger instances.
    """

    loggers = {}

    def get_logger(self, name=__name__):
        """
        Retrieves or creates a logger instance for the given name.
        """
        if name in self.loggers:
            return self.loggers[name]

        self.loggers[name] = logging.getLogger(name)

        return self.loggers[name]
